# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2011 <Davide Vescovini> <davide.vescovini@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

################################################################################
############# IMPORTAZIONE MODULI ##############################################
################################################################################
import datetime
from gi.repository import Gtk
from preventares_lib.helpers import get_builder
from preventares_lib import metel_lib
################################################################################
############ SUPPORTO INTERNAZIONALIZZAZIONE ###################################
################################################################################
import gettext
from gettext import gettext as _
gettext.textdomain('preventares')
################################################################################
############# DIALOG ###########################################################
################################################################################
class AddmetelDialog(Gtk.Dialog):
    __gtype_name__ = "AddmetelDialog"

    def __new__(cls):
        """Special static method that's automatically called by Python when 
        constructing a new instance of this class.
        
        Returns a fully instantiated AddmetelDialog object.
        """
        builder = get_builder('AddmetelDialog')
        new_object = builder.get_object('addmetel_dialog')
        new_object.finish_initializing(builder)
        return new_object

    def finish_initializing(self, builder):
        """Called when we're finished initializing.

        finish_initalizing should be called after parsing the ui definition
        and creating a AddmetelDialog object with it in order to
        finish initializing the start of the new AddmetelDialog
        instance.
        """
        # Get a reference to the builder and set up the signals.
        self.builder = builder
        self.builder.connect_signals(self)
        # inizializzazione variabili
        self.art_metel = None
        # setup Gtk-Entry callbacks
        self.entry = [None]*19
        for n in range(19):
            # add treeview reference and setup callbacks
            self.entry[n] = builder.get_object("entry%d" % (n+1))
            self.entry[n].connect('activate', self.callback_entry, n)
            self.entry[n].set_overwrite_mode(True)
        # imposta la data attuale nel campo data
        data = "{0:%Y%m%d}".format(datetime.datetime.now())
        self.entry[16].set_text(data)

################################################################################
############# CALLBACKS ########################################################
################################################################################

    def callback_entry(self, widget, data=None):
        if len(widget.get_text()) < widget.get_max_length():
            self.message(self, "errore", _("Questo campo richiede almeno {0} caratteri").format(widget.get_max_length()))
        if data in [9,10]:
            try: 
                prezzo = float(widget.get_text().replace(",", "."))
            except:
                self.message(self, "errore", _("Inserire solo valori numerici"))
                prezzo = 0
            prezzo = int(100*round(prezzo,2))
            text = "0"*(widget.get_max_length()-len(str(prezzo))) + str(prezzo)
            widget.set_text(text)

    def ok(self, widget, data=None):
        """The user has elected to save the changes.

        Called before the dialog returns Gtk.ResponseType.OK from run().
        """
        if self.entry[0].get_text() == '' or self.entry[1].get_text() == '' or \
           self.entry[3].get_text() == '':
            self.message(self, "errore", _("Compilare tutti i campi obbligatori {0}").format(''))
            return False
        # crea l'articolo METEL
        self.art_metel = metel_lib.ArticoloMetel(
                      SiglaMarchio = self.entry[0].get_text(), 
                      CodiceProdAzienda = self.entry[1].get_text(), 
                      CodiceEAN = self.entry[2].get_text(),
                      DescrizioneProdotto = self.entry[3].get_text(), 
                      QuantitaCartone = self.entry[4].get_text(),
                      QuantitaMulOrdinazione = self.entry[5].get_text(), 
                      QuantitaMinOrdinazione = self.entry[6].get_text(),
                      QuantitaMaxOrdinazione = self.entry[7].get_text(), 
                      LeadTime = self.entry[8].get_text(), 
                      PrezzoRivenditore = self.entry[9].get_text(), 
                      PrezzoPubblico = self.entry[10].get_text(),
                      MoltiplicatorePrezzo = self.entry[11].get_text(), 
                      CodiceValuta = self.entry[12].get_text(),
                      UnitaMisura = self.entry[13].get_text(),
                      ProdottoComposto = self.entry[14].get_text(), 
                      StatoProdotto = self.entry[15].get_text(),
                      DataUltimaVariazione = self.entry[16].get_text(), 
                      FamigliaSconto = self.entry[17].get_text(),
                      FamigliaStatistica = self.entry[18].get_text())
        pass # str(self.art_metel)

    def cancel(self, widget, data=None):
        """The user has elected cancel changes.

        Called before the dialog returns Gtk.ResponseType.CANCEL for run()
        """
        pass
################################################################################
###  FINESTRA MESSAGGI UTENTE ##################################################
################################################################################
    def message(self, widget, tipo, testo, data=None):
        """display a message windows"""
        buttons = Gtk.ButtonsType.OK_CANCEL
        if tipo == "info":
           tipo = Gtk.MessageType.INFO
           buttons = Gtk.ButtonsType.CLOSE
        elif tipo == "avviso":
           tipo = Gtk.MessageType.WARNING
        elif tipo == "domanda":
           tipo = Gtk.MessageType.QUESTION
        elif tipo == "errore":
           tipo = Gtk.MessageType.ERROR
           buttons = Gtk.ButtonsType.CLOSE
        else:
           tipo == Gtk.MessageType.INFO
           buttons = Gtk.ButtonsType.CLOSE
        message = Gtk.MessageDialog(parent=None, flags=0, type=tipo, buttons = buttons, message_format=testo)
        message.format_secondary_text(_("Premere un pulsante per continuare"))
        response = message.run()
        if response == Gtk.ResponseType.OK:
           response = True
        else:
           response = False 
        message.destroy()
        return response
################################################################################
################################################################################
if __name__ == "__main__":
    dialog = AddmetelDialog()
    dialog.show()
    Gtk.main()
